import { alertStore } from '../../Stores/NoticeStore';
/**
 * Submit action
 *
 * @since 1.0.0
 */
export default class ActionSubmit {
    actionData;
    formValues;
    /**
    * Constuctor.
    *
    * @param actionData Action data.
    * @param form Form object.
    *
    * @since 1.0.0
    */
    constructor(actionData, formValues = {}) {
        this.actionData = actionData;
        this.formValues = formValues;
    }
    /**
     * Get headers to send.
     *
     * @returns Headers to send.
     *
     * @since 1.0.0
     */
    getHeaders() {
        if (this.actionData.format === 'json') {
            return {
                'Content-Type': 'application/json'
            };
        }
        return {
            'Content-Type': 'application/x-www-form-urlencoded',
        };
    }
    /**
     * Get body to send.
     *
     * @returns Body to send.
     *
     * @since 1.0.0
     */
    getBody() {
        // JSON Body
        if (this.actionData.format === 'json') {
            return JSON.stringify(this.formValues);
        }
        // Form Data Body
        let formData = new FormData();
        for (let key in this.formValues) {
            formData.append(key, this.formValues[key]);
        }
        return formData;
    }
    /**
     * Get url to send.
     *
     * @returns Url to send.
     *
     * @since 1.0.0
     */
    getUrl() {
        return this.actionData.url;
    }
    /**
     * Get action method.
     *
     * @returns Action method.
     *
     * @since 1.0.0
     */
    getMethod() {
        return this.actionData.method;
    }
    /**
     * Run action.
     *
     * @since 1.0.0
     */
    execute() {
        fetch(this.getUrl(), {
            method: this.getMethod(),
            headers: this.getHeaders(),
            body: this.getBody(),
            credentials: 'same-origin',
            redirect: 'follow',
            referrerPolicy: 'no-referrer'
        }).then((response) => {
            if (response.ok) {
                this.setSuccess();
            }
            else {
                this.setError();
                return false;
            }
        }).catch((error) => {
            console.log(error);
            this.setError();
            return false;
        });
        return true;
    }
    /**
     * Set error.
     *
     * @since 1.0.0
     */
    setError() {
        if (this.actionData.error.message) {
            let data = {
                message: this.actionData.error.message,
                type: this.actionData.error.type
            };
            alertStore.set(data);
        }
    }
    /**
     * Set success.
     *
     * @since 1.0.0
     */
    setSuccess() {
        if (this.actionData.success.message) {
            let data = {
                message: this.actionData.success.message,
                type: this.actionData.success.type
            };
            alertStore.set(data);
        }
    }
}
